package BadTraffic2::Template;

use warnings;
use strict;
use Carp;

# exports
use base qw( Exporter );
our @EXPORT      = qw( );
our @EXPORT_OK   = qw( );
our %EXPORT_TAGS = (
    ALL => [ @EXPORT, @EXPORT_OK ],    # if :ALL requested
);

=head1 NAME

BadTraffic2::Template - Firewall handler template

=head1 SYNOPSIS

This code is used internally.
  
=head1 DESCRIPTION

Example of a BadTraffic2 firewall handler.

=head1 INTERFACE 

There are no public methods.

=cut

=head2 new

Initialize the handler.

=cut

sub new {
    my ( $class, %parameters ) = @_;

    # defaults and valid keys
    my $self = bless(
        {   FW_NAME => 'badtraffic',
            DEBUG   => 0,
        },
        ref($class) || $class
    );

    foreach my $key ( sort keys %parameters ) {
        if ( defined $self->{$key} ) {
            $self->{$key} = $parameters{$key};
        }
        else {
            # quietly ignore extra params
        }
    }

    # tests to make sure the handler can be used

    # entry = tell upstream code that we prefer to update individual entries
    # all = tell upstream code that we prefer to rewrite the entire list
    $self->{_UPDATES} = 'entry';

    return ($self);
}

=head2 config_check 

Check and fix firewall configuration

=cut 

sub config_check {
    my $self = shift;

}

=head2 read_set

Read list of blocked addresses as a set object.

=cut 

sub read_set {
    my $self = shift;
    my $raw = shift;   # if true, return an array of entries

    return Net::CIDR::Set->new( { type => 'ipv4' } );
}

=head2 write_set 

Write entire list of addresses, removing previous contents.

=cut

sub write_set {
    my $self    = shift;
    my $cidrset = shift;

}

=head2 add_entry 

Add a single ip/cidr rule to the existing list.

=cut

sub add_entry {
    my $self   = shift;
    my $ipcidr = shift;
}

=head2 del_entry

Remove a single ip/cidr rule from the existing list.

=cut 

sub del_entry {
    my $self   = shift;
    my $ipcidr = shift;
}

=head2 commit

Update synchronize all changes

=cut

sub commit {
    my $self = shift;
}

1;    # Magic true value required at end of module
__END__

=head1 AUTHOR

Charles J. Brabec  C<< <brabec@ncsu.edu> >>


=head1 LICENCE AND COPYRIGHT

Copyright (c) 2019, Charles J. Brabec C<< <brabec@ncsu.edu> >>. All rights reserved.

This module is free software; you can redistribute it and/or
modify it under the same terms as Perl itself. See L<perlartistic>.


=head1 DISCLAIMER OF WARRANTY

BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
NECESSARY SERVICING, REPAIR, OR CORRECTION.

IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENCE, BE
LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
SUCH DAMAGES.
